@@ -285,6 +285,8 @@ def _create_month_list(start_date, end_date):
         if current.month == start_date.month:
             # First month start with start_date
             month["start"] = start_date
+        if current.month < end_date.month:
+            month["end"] = (month.get("end") + relativedelta(days=1)).replace(hour=0, minute=0)
         if current.month == end_date.month:
             # Last month ends with end_date
             month["end"] = end_date.replace(hour=23, minute=59)
@@ -416,7 +418,7 @@ def _create_generator_dates_from_yaml(attributes, month):
         hour=23, minute=59, second=59
     ):
         gen_start_date = month.get("start")
-        gen_end_date = month.get("end") + relativedelta(days=1)
+        gen_end_date = month.get("end")
 
     # Generator starts before month start and ends within month
     if attributes.get("start_date") <= month.get("start") and attributes.get("end_date") <= month.get("end").replace(
@@ -437,7 +439,7 @@ def _create_generator_dates_from_yaml(attributes, month):
         hour=23, minute=59, second=59
     ):
         gen_start_date = attributes.get("start_date")
-        gen_end_date = month.get("end") + relativedelta(days=1)
+        gen_end_date = month.get("end")
 
     return gen_start_date, gen_end_date
 
@@ -762,6 +764,38 @@ def ocp_create_report(options):  # noqa: C901
                 temp_files[temp_filename] = temp_usage_file
 
             manifest_file_names = ", ".join(f'"{w}"' for w in temp_files)
+            cr_status = {
+                "clusterID": "4e009161-4f40-42c8-877c-3e59f6baea3d",
+                "clusterVersion": "stable-4.6",
+                "api_url": "https://cloud.redhat.com",
+                "authentication": {"type": "token"},
+                "packaging": {"max_reports_to_store": 30, "max_size_MB": 100},
+                "upload": {
+                    "ingress_path": "/api/ingress/v1/upload",
+                    "upload": True,
+                    "upload_wait": 27,
+                    "upload_cycle": 360,
+                },
+                "operator_commit": __version__,
+                "prometheus": {
+                    "prometheus_configured": True,
+                    "prometheus_connected": True,
+                    "last_query_start_time": "2021-07-28T12:22:37Z",
+                    "last_query_success_time": "2021-07-28T12:22:37Z",
+                    "service_address": "https://thanos-querier.openshift-monitoring.svc:9091",
+                },
+                "reports": {
+                    "report_month": "07",
+                    "last_hour_queried": "2021-07-28 11:00:00 - 2021-07-28 11:59:59",
+                    "data_collected": True,
+                },
+                "source": {
+                    "sources_path": "/api/sources/v1.0/",
+                    "name": "INSERT-SOURCE-NAME",
+                    "create_source": False,
+                    "check_cycle": 1440,
+                },
+            }
             manifest_values = {
                 "ocp_cluster_id": cluster_id,
                 "ocp_assembly_id": ocp_assembly_id,
@@ -770,6 +804,8 @@ def ocp_create_report(options):  # noqa: C901
                 "start": gen_start_date,
                 "end": gen_end_date,
                 "version": __version__,
+                "certified": False,
+                "cr_status": cr_status,
             }
             manifest_data = ocp_generate_manifest(manifest_values)
             temp_manifest = _write_manifest(manifest_data)
@@ -894,6 +930,55 @@ def gcp_create_report(options):  # noqa: C901
         project_generator = ProjectGenerator(account)
         projects = project_generator.generate_projects()
 
+    if gcp_dataset_name:
+        monthly_files = _gcp_bigquery_process(
+            start_date, end_date, projects, generators, options, gcp_bucket_name, gcp_dataset_name, gcp_table_name
+        )
+    else:
+        months = _create_month_list(start_date, end_date)
+        monthly_files = []
+        output_files = []
+        for month in months:
+            data = []
+            gen_start_date = month.get("start")
+            gen_end_date = month.get("end")
+            for project in projects:
+                num_gens = len(generators)
+                ten_percent = int(num_gens * 0.1) if num_gens > 50 else 5
+                LOG.info(
+                    f"Producing data for {num_gens} generators for start: {gen_start_date} and end: {gen_end_date}."
+                )
+                for count, generator in enumerate(generators):
+                    attributes = generator.get("attributes", {})
+                    if attributes:
+                        start_date = attributes.get("start_date")
+                        end_date = attributes.get("end_date")
+                    if gen_end_date > end_date:
+                        gen_end_date = end_date
+
+                    generator_cls = generator.get("generator")
+                    gen = generator_cls(gen_start_date, gen_end_date, project, attributes=attributes)
+                    for hour in gen.generate_data():
+                        data += [hour]
+                    count += 1
+                    if count % ten_percent == 0:
+                        LOG.info(f"Done with {count} of {num_gens} generators.")
+            local_file_path, output_file_name = write_gcp_file(gen_start_date, gen_end_date, data, options)
+            output_files.append(output_file_name)
+            monthly_files.append(local_file_path)
+
+        for index, month_file in enumerate(monthly_files):
+            if gcp_bucket_name:
+                gcp_route_file(gcp_bucket_name, month_file, output_files[index])
+
+    write_monthly = options.get("write_monthly", False)
+    if not write_monthly:
+        _remove_files(monthly_files)
+
+
+def _gcp_bigquery_process(
+    start_date, end_date, projects, generators, options, gcp_bucket_name, gcp_dataset_name, gcp_table_name
+):
     data = []
     for project in projects:
         num_gens = len(generators)
@@ -914,22 +999,15 @@ def gcp_create_report(options):  # noqa: C901
                 LOG.info(f"Done with {count} of {num_gens} generators.")
 
     monthly_files = []
-    if not gcp_dataset_name:
-        local_file_path, output_file_name = write_gcp_file(start_date, end_date, data, options)
-        monthly_files.append(local_file_path)
-    else:
-        local_file_path, output_file_name = write_gcp_file_jsonl(start_date, end_date, data, options)
-        monthly_files.append(local_file_path)
+    local_file_path, output_file_name = write_gcp_file_jsonl(start_date, end_date, data, options)
+    monthly_files.append(local_file_path)
 
     if gcp_bucket_name:
         gcp_route_file(gcp_bucket_name, local_file_path, output_file_name)
 
-    if gcp_dataset_name:
-        if not gcp_table_name:
-            etag = options.get("gcp_etag") if options.get("gcp_etag") else str(uuid4())
-            gcp_table_name = f"gcp_billing_export_{etag}"
-        gcp_bucket_to_dataset(gcp_bucket_name, output_file_name, gcp_dataset_name, gcp_table_name)
+    if not gcp_table_name:
+        etag = options.get("gcp_etag") if options.get("gcp_etag") else str(uuid4())
+        gcp_table_name = f"gcp_billing_export_{etag}"
+    gcp_bucket_to_dataset(gcp_bucket_name, output_file_name, gcp_dataset_name, gcp_table_name)
 
-    write_monthly = options.get("write_monthly", False)
-    if not write_monthly:
-        _remove_files(monthly_files)
+    return monthly_files
